Struct
SpiceClientGLibDisplayPrimary
Description [src]
struct SpiceDisplayPrimary {
SpiceSurfaceFmt format;
gint width;
gint height;
gint stride;
gint shmid;
guint8* data;
gboolean marked;
}
Holds the information necessary to use the primary surface.
Structure members
format:SpiceSurfaceFmtPrimary buffer format.
width:gintWidth of the primary.
height:gintHeight of the primary.
stride:gintStride of the primary.
shmid:gintIdentifier of the shared memory segment associated with the
data, or -1 if not shm.data:guint8*Pointer to primary buffer.
marked:gbooleanWhether the display is marked ready.