Struct

SpiceClientGLibUsbDevice

Description [src]

struct SpiceUsbDevice {
  /* No available fields */
}

The SpiceUsbDevice struct is opaque and cannot be accessed directly.

Instance methods

spice_usb_device_get_description

Get a string describing the device which is suitable as a description of the device for the end user. The returned string should be freed with g_free() when no longer needed.

spice_usb_device_get_libusb_device

Finds the %libusb_device associated with the device.

since: 0.27